PyXMake Developer Guide: PyXMake.__install__ Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Functions
PyXMake.__install__ Namespace Reference

Development code installation procedure for PyXMake. More...

## Functions
| main ()

## Detailed Description

Development code installation procedure for PyXMake.

    Development code installation procedure for PyXMake.

    @note: PyXMake installation file for development code.
    Created on 22.08.2020

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  22.08.2020

Notes/Changes
  - Added documentation // mg 22.08.2020

## Function Documentation

## ◆ main()

PyXMake.__install__.main | ( |  | ) |

Definition at line 40 of file __install__.py.